# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workitems.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import ace_pb2 as ace__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkitems.proto\x12\x07openiap\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\tace.proto\"\xaa\x03\n\x08workitem\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12+\n\x07nextrun\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07lastrun\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x05\x66iles\x18\x07 \x03(\x0b\x32\x15.openiap.workitemfile\x12\r\n\x05state\x18\x08 \x01(\t\x12\x0b\n\x03wiq\x18\t \x01(\t\x12\r\n\x05wiqid\x18\n \x01(\t\x12\x0f\n\x07retries\x18\x0b \x01(\x05\x12\x10\n\x08username\x18\x0c \x01(\t\x12\x15\n\rsuccess_wiqid\x18\r \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x0e \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0f \x01(\t\x12\x12\n\nfailed_wiq\x18\x10 \x01(\t\x12\x14\n\x0c\x65rrormessage\x18\x11 \x01(\t\x12\x13\n\x0b\x65rrorsource\x18\x12 \x01(\t\x12\x11\n\terrortype\x18\x13 \x01(\t\"O\n\x0cworkitemfile\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03_id\x18\x02 \x01(\t\x12\x12\n\ncompressed\x18\x03 \x01(\x08\x12\x0c\n\x04\x66ile\x18\x04 \x01(\x0c\"\x84\x02\n\x0cpushworkitem\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\t\x12+\n\x07nextrun\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rsuccess_wiqid\x18\x06 \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x07 \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x08 \x01(\t\x12\x12\n\nfailed_wiq\x18\t \x01(\t\x12\x10\n\x08priority\x18\n \x01(\x05\x12$\n\x05\x66iles\x18\x0b \x03(\x0b\x32\x15.openiap.workitemfile\"8\n\x11pushworkitemreply\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.workitem\"\xe2\x01\n\rpushworkitems\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12+\n\x07nextrun\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rsuccess_wiqid\x18\x04 \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\x05 \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x06 \x01(\t\x12\x12\n\nfailed_wiq\x18\x07 \x01(\t\x12\x10\n\x08priority\x18\x08 \x01(\x05\x12 \n\x05items\x18\t \x03(\x0b\x32\x11.openiap.workitem\":\n\x12pushworkitemsreply\x12$\n\tworkitems\x18\x01 \x03(\x0b\x32\x11.openiap.workitem\"O\n\x0eupdateworkitem\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.workitem\x12\x18\n\x10ignoremaxretries\x18\x02 \x01(\x08\":\n\x13updateworkitemreply\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.workitem\"S\n\x0bpopworkitem\x12\x0b\n\x03wiq\x18\x01 \x01(\t\x12\r\n\x05wiqid\x18\x02 \x01(\t\x12\x14\n\x0cincludefiles\x18\x03 \x01(\x08\x12\x12\n\ncompressed\x18\x04 \x01(\x08\"7\n\x10popworkitemreply\x12#\n\x08workitem\x18\x01 \x01(\x0b\x32\x11.openiap.workitem\"\x1d\n\x0e\x64\x65leteworkitem\x12\x0b\n\x03_id\x18\x01 \x01(\t\"\x15\n\x13\x64\x65leteworkitemreply\"\x80\x04\n\rworkitemqueue\x12\x12\n\nworkflowid\x18\x01 \x01(\t\x12\x12\n\nrobotqueue\x18\x02 \x01(\t\x12\x11\n\tamqpqueue\x18\x03 \x01(\t\x12\x11\n\tprojectid\x18\x04 \x01(\t\x12\x11\n\tusersrole\x18\x05 \x01(\t\x12\x12\n\nmaxretries\x18\x06 \x01(\x05\x12\x12\n\nretrydelay\x18\x07 \x01(\x05\x12\x14\n\x0cinitialdelay\x18\x08 \x01(\x05\x12\x15\n\rsuccess_wiqid\x18\t \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\n \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0b \x01(\t\x12\x12\n\nfailed_wiq\x18\x0c \x01(\t\x12\x0b\n\x03_id\x18\r \x01(\t\x12\x1a\n\x04_acl\x18\x0e \x03(\x0b\x32\x0c.openiap.ace\x12\x0c\n\x04name\x18\x0f \x01(\t\x12\x14\n\x0c_createdbyid\x18\x10 \x01(\t\x12\x12\n\n_createdby\x18\x11 \x01(\t\x12,\n\x08_created\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\r_modifiedbyid\x18\x13 \x01(\t\x12\x13\n\x0b_modifiedby\x18\x14 \x01(\t\x12-\n\t_modified\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08_version\x18\x16 \x01(\x05\"\x9c\x02\n\x10\x61\x64\x64workitemqueue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nrobotqueue\x18\x02 \x01(\t\x12\x11\n\tamqpqueue\x18\x03 \x01(\t\x12\x11\n\tprojectid\x18\x04 \x01(\t\x12\x10\n\x08skiprole\x18\x05 \x01(\x08\x12\x12\n\nmaxretries\x18\x06 \x01(\x05\x12\x14\n\x0cinitialdelay\x18\x07 \x01(\x05\x12\x12\n\nretrydelay\x18\x08 \x01(\x05\x12\x15\n\rsuccess_wiqid\x18\t \x01(\t\x12\x14\n\x0c\x66\x61iled_wiqid\x18\n \x01(\t\x12\x13\n\x0bsuccess_wiq\x18\x0b \x01(\t\x12\x12\n\nfailed_wiq\x18\x0c \x01(\t\x12\x1a\n\x04_acl\x18\r \x03(\x0b\x32\x0c.openiap.ace\"F\n\x15\x61\x64\x64workitemqueuereply\x12-\n\rworkitemqueue\x18\x01 \x01(\x0b\x32\x16.openiap.workitemqueueb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workitems_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKITEM._serialized_start=73
  _WORKITEM._serialized_end=499
  _WORKITEMFILE._serialized_start=501
  _WORKITEMFILE._serialized_end=580
  _PUSHWORKITEM._serialized_start=583
  _PUSHWORKITEM._serialized_end=843
  _PUSHWORKITEMREPLY._serialized_start=845
  _PUSHWORKITEMREPLY._serialized_end=901
  _PUSHWORKITEMS._serialized_start=904
  _PUSHWORKITEMS._serialized_end=1130
  _PUSHWORKITEMSREPLY._serialized_start=1132
  _PUSHWORKITEMSREPLY._serialized_end=1190
  _UPDATEWORKITEM._serialized_start=1192
  _UPDATEWORKITEM._serialized_end=1271
  _UPDATEWORKITEMREPLY._serialized_start=1273
  _UPDATEWORKITEMREPLY._serialized_end=1331
  _POPWORKITEM._serialized_start=1333
  _POPWORKITEM._serialized_end=1416
  _POPWORKITEMREPLY._serialized_start=1418
  _POPWORKITEMREPLY._serialized_end=1473
  _DELETEWORKITEM._serialized_start=1475
  _DELETEWORKITEM._serialized_end=1504
  _DELETEWORKITEMREPLY._serialized_start=1506
  _DELETEWORKITEMREPLY._serialized_end=1527
  _WORKITEMQUEUE._serialized_start=1530
  _WORKITEMQUEUE._serialized_end=2042
  _ADDWORKITEMQUEUE._serialized_start=2045
  _ADDWORKITEMQUEUE._serialized_end=2329
  _ADDWORKITEMQUEUEREPLY._serialized_start=2331
  _ADDWORKITEMQUEUEREPLY._serialized_end=2401
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbase.proto\x12\x07openiap\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\xa6\x01\n\x08\x65nvelope\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12\x0b\n\x03seq\x18\x03 \x01(\x05\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0b\n\x03rid\x18\x06 \x01(\t\x12\x0f\n\x07traceid\x18\x07 \x01(\t\x12\x0e\n\x06spanid\x18\x08 \x01(\t\x12\"\n\x04\x64\x61ta\x18\t \x01(\x0b\x32\x14.google.protobuf.Any\"\x06\n\x04noop\"\x06\n\x04ping\"\x06\n\x04pong\"5\n\x05\x65rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\r\n\x05stack\x18\x03 \x01(\t\"\x1b\n\ngetelement\x12\r\n\x05xpath\x18\x01 \x01(\t\"\x15\n\x04send\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"(\n\x08\x64ownload\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\"?\n\rdownloadreply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x10\n\x08mimetype\x18\x03 \x01(\t\",\n\x06upload\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x10\n\x08mimetype\x18\x02 \x01(\t\"y\n\x0buploadreply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\r\n\x05\x62ytes\x18\x03 \x01(\x05\x12\x0e\n\x06\x63hunks\x18\x04 \x01(\x05\x12\n\n\x02mb\x18\x05 \x01(\x02\x12\x13\n\x0b\x65lapsedTime\x18\x06 \x01(\x05\x12\x0c\n\x04mbps\x18\x07 \x01(\x02\"\t\n\x07\x63onsole\"\x0f\n\rclientconsole\"<\n\x0b\x62\x65ginstream\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x1b\n\x04stat\x18\x02 \x01(\x0b\x32\r.openiap.stat\"\x16\n\x06stream\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x0b\n\tendstream\"\xa1\x02\n\x04stat\x12\x13\n\x0b\x62irthtimeMs\x18\x01 \x01(\x02\x12\x0f\n\x07\x62lksize\x18\x02 \x01(\x05\x12\x0e\n\x06\x62locks\x18\x03 \x01(\x05\x12)\n\x05\x63time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63timeMs\x18\x05 \x01(\x02\x12\x0b\n\x03\x64\x65v\x18\x06 \x01(\x05\x12\x0b\n\x03gid\x18\x07 \x01(\x05\x12\x0b\n\x03ino\x18\x08 \x01(\x05\x12\x0c\n\x04mode\x18\t \x01(\x05\x12)\n\x05mtime\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07mtimeMs\x18\x0b \x01(\x02\x12\r\n\x05nlink\x18\x0c \x01(\x05\x12\x0c\n\x04rdev\x18\r \x01(\x05\x12\x0c\n\x04size\x18\x0e \x01(\x05\x12\x0b\n\x03uid\x18\x0f \x01(\x05\"H\n\rcustomcommand\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t\"$\n\x12\x63ustomcommandreply\x12\x0e\n\x06result\x18\x01 \x01(\t\"G\n\x06signin\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0b\n\x03jwt\x18\x03 \x01(\t\x12\x0c\n\x04ping\x18\x04 \x01(\x08\"7\n\x0bsigninreply\x12\x0b\n\x03jwt\x18\x01 \x01(\t\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.openiap.user\"J\n\x0crefreshtoken\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0b\n\x03jwt\x18\x02 \x01(\t\x12\x1b\n\x04user\x18\x03 \x01(\x0b\x32\r.openiap.user\"!\n\x04role\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"`\n\x04user\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x1c\n\x05roles\x18\x05 \x03(\x0b\x32\r.openiap.role2y\n\x0bgrpcService\x12\x39\n\x0bSetupStream\x12\x11.openiap.envelope\x1a\x11.openiap.envelope\"\x00(\x01\x30\x01\x12/\n\x06Signin\x12\x0f.openiap.signin\x1a\x14.openiap.signinreplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVELOPE._serialized_start=84
  _ENVELOPE._serialized_end=250
  _NOOP._serialized_start=252
  _NOOP._serialized_end=258
  _PING._serialized_start=260
  _PING._serialized_end=266
  _PONG._serialized_start=268
  _PONG._serialized_end=274
  _ERROR._serialized_start=276
  _ERROR._serialized_end=329
  _GETELEMENT._serialized_start=331
  _GETELEMENT._serialized_end=358
  _SEND._serialized_start=360
  _SEND._serialized_end=381
  _DOWNLOAD._serialized_start=383
  _DOWNLOAD._serialized_end=423
  _DOWNLOADREPLY._serialized_start=425
  _DOWNLOADREPLY._serialized_end=488
  _UPLOAD._serialized_start=490
  _UPLOAD._serialized_end=534
  _UPLOADREPLY._serialized_start=536
  _UPLOADREPLY._serialized_end=657
  _CONSOLE._serialized_start=659
  _CONSOLE._serialized_end=668
  _CLIENTCONSOLE._serialized_start=670
  _CLIENTCONSOLE._serialized_end=685
  _BEGINSTREAM._serialized_start=687
  _BEGINSTREAM._serialized_end=747
  _STREAM._serialized_start=749
  _STREAM._serialized_end=771
  _ENDSTREAM._serialized_start=773
  _ENDSTREAM._serialized_end=784
  _STAT._serialized_start=787
  _STAT._serialized_end=1076
  _CUSTOMCOMMAND._serialized_start=1078
  _CUSTOMCOMMAND._serialized_end=1150
  _CUSTOMCOMMANDREPLY._serialized_start=1152
  _CUSTOMCOMMANDREPLY._serialized_end=1188
  _SIGNIN._serialized_start=1190
  _SIGNIN._serialized_end=1261
  _SIGNINREPLY._serialized_start=1263
  _SIGNINREPLY._serialized_end=1318
  _REFRESHTOKEN._serialized_start=1320
  _REFRESHTOKEN._serialized_end=1394
  _ROLE._serialized_start=1396
  _ROLE._serialized_end=1429
  _USER._serialized_start=1431
  _USER._serialized_end=1527
  _GRPCSERVICE._serialized_start=1529
  _GRPCSERVICE._serialized_end=1650
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ace.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tace.proto\x12\x07openiap\"0\n\x03\x61\x63\x65\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65ny\x18\x02 \x01(\x08\x12\x0e\n\x06rights\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ace_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACE._serialized_start=22
  _ACE._serialized_end=70
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: queues.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cqueues.proto\x12\x07openiap\"\"\n\rregisterqueue\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\'\n\x12registerqueuereply\x12\x11\n\tqueuename\x18\x01 \x01(\t\"a\n\x10registerexchange\x12\x14\n\x0c\x65xchangename\x18\x01 \x01(\t\x12\x11\n\talgorithm\x18\x02 \x01(\t\x12\x12\n\nroutingkey\x18\x03 \x01(\t\x12\x10\n\x08\x61\x64\x64queue\x18\x04 \x01(\x08\"*\n\x15registerexchangereply\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\x95\x01\n\x0cqueuemessage\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\x12\x12\n\nstriptoken\x18\x07 \x01(\x08\"\x86\x01\n\x11queuemessagereply\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"\x7f\n\nqueueevent\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"$\n\x0funregisterqueue\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\x16\n\x14unregisterqueuereplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'queues_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTERQUEUE._serialized_start=25
  _REGISTERQUEUE._serialized_end=59
  _REGISTERQUEUEREPLY._serialized_start=61
  _REGISTERQUEUEREPLY._serialized_end=100
  _REGISTEREXCHANGE._serialized_start=102
  _REGISTEREXCHANGE._serialized_end=199
  _REGISTEREXCHANGEREPLY._serialized_start=201
  _REGISTEREXCHANGEREPLY._serialized_end=243
  _QUEUEMESSAGE._serialized_start=246
  _QUEUEMESSAGE._serialized_end=395
  _QUEUEMESSAGEREPLY._serialized_start=398
  _QUEUEMESSAGEREPLY._serialized_end=532
  _QUEUEEVENT._serialized_start=534
  _QUEUEEVENT._serialized_end=661
  _UNREGISTERQUEUE._serialized_start=663
  _UNREGISTERQUEUE._serialized_end=699
  _UNREGISTERQUEUEREPLY._serialized_start=701
  _UNREGISTERQUEUEREPLY._serialized_end=723
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: querys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cquerys.proto\x12\x07openiap\"&\n\x0flistcollections\x12\x13\n\x0bincludehist\x18\x01 \x01(\x08\"\'\n\x14listcollectionsreply\x12\x0f\n\x07results\x18\x01 \x01(\t\"(\n\x0e\x64ropcollection\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\"\x15\n\x13\x64ropcollectionreply\"\x7f\n\x05query\x12\r\n\x05query\x18\x01 \x01(\t\x12\x16\n\x0e\x63ollectionname\x18\x02 \x01(\t\x12\x12\n\nprojection\x18\x03 \x01(\t\x12\x0b\n\x03top\x18\x04 \x01(\x05\x12\x0c\n\x04skip\x18\x05 \x01(\x05\x12\x0f\n\x07orderby\x18\x06 \x01(\t\x12\x0f\n\x07queryas\x18\x07 \x01(\t\"\x1d\n\nqueryreply\x12\x0f\n\x07results\x18\x01 \x01(\t\"Z\n\x12getdocumentversion\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65\x63rypt\x18\x04 \x01(\x08\")\n\x17getdocumentversionreply\x12\x0e\n\x06result\x18\x01 \x01(\t\"V\n\taggregate\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x12\n\naggregates\x18\x02 \x01(\t\x12\x0f\n\x07queryas\x18\x03 \x01(\t\x12\x0c\n\x04hint\x18\x04 \x01(\t\"!\n\x0e\x61ggregatereply\x12\x0f\n\x07results\x18\x01 \x01(\t\"?\n\x05\x63ount\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x0f\n\x07queryas\x18\x03 \x01(\t\"\x1c\n\ncountreply\x12\x0e\n\x06result\x18\x01 \x01(\x05\"G\n\tinsertone\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x0c\n\x04item\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\" \n\x0einsertonereply\x12\x0e\n\x06result\x18\x01 \x01(\t\"^\n\ninsertmany\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05items\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\x12\x13\n\x0bskipresults\x18\x05 \x01(\x08\"\"\n\x0finsertmanyreply\x12\x0f\n\x07results\x18\x01 \x01(\t\"G\n\tupdateone\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x0c\n\x04item\x18\x02 \x01(\t\x12\t\n\x01w\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x08\" \n\x0eupdateonereply\x12\x0e\n\x06result\x18\x01 \x01(\t\"_\n\x0eupdatedocument\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x10\n\x08\x64ocument\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\"|\n\x0cupdateresult\x12\x14\n\x0c\x61\x63knowledged\x18\x01 \x01(\x08\x12\x14\n\x0cmatchedCount\x18\x02 \x01(\x05\x12\x15\n\rmodifiedCount\x18\x03 \x01(\x05\x12\x15\n\rupsertedCount\x18\x04 \x01(\x05\x12\x12\n\nupsertedId\x18\x05 \x01(\t\">\n\x13updatedocumentreply\x12\'\n\x08opresult\x18\x01 \x01(\x0b\x32\x15.openiap.updateresult\"b\n\x11insertorupdateone\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x11\n\tuniqeness\x18\x02 \x01(\t\x12\x0c\n\x04item\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\"(\n\x16insertorupdateonereply\x12\x0e\n\x06result\x18\x01 \x01(\t\"y\n\x12insertorupdatemany\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\x11\n\tuniqeness\x18\x02 \x01(\t\x12\r\n\x05items\x18\x03 \x01(\t\x12\t\n\x01w\x18\x04 \x01(\x05\x12\t\n\x01j\x18\x05 \x01(\x08\x12\x13\n\x0bskipresults\x18\x06 \x01(\x08\"*\n\x17insertorupdatemanyreply\x12\x0f\n\x07results\x18\x01 \x01(\t\"B\n\tdeleteone\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\"&\n\x0e\x64\x65leteonereply\x12\x14\n\x0c\x61\x66\x66\x65\x63tedrows\x18\x01 \x01(\x05\"S\n\ndeletemany\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\x12\x0b\n\x03ids\x18\x04 \x03(\t\"\'\n\x0f\x64\x65letemanyreply\x12\x14\n\x0c\x61\x66\x66\x65\x63tedrows\x18\x01 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'querys_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LISTCOLLECTIONS._serialized_start=25
  _LISTCOLLECTIONS._serialized_end=63
  _LISTCOLLECTIONSREPLY._serialized_start=65
  _LISTCOLLECTIONSREPLY._serialized_end=104
  _DROPCOLLECTION._serialized_start=106
  _DROPCOLLECTION._serialized_end=146
  _DROPCOLLECTIONREPLY._serialized_start=148
  _DROPCOLLECTIONREPLY._serialized_end=169
  _QUERY._serialized_start=171
  _QUERY._serialized_end=298
  _QUERYREPLY._serialized_start=300
  _QUERYREPLY._serialized_end=329
  _GETDOCUMENTVERSION._serialized_start=331
  _GETDOCUMENTVERSION._serialized_end=421
  _GETDOCUMENTVERSIONREPLY._serialized_start=423
  _GETDOCUMENTVERSIONREPLY._serialized_end=464
  _AGGREGATE._serialized_start=466
  _AGGREGATE._serialized_end=552
  _AGGREGATEREPLY._serialized_start=554
  _AGGREGATEREPLY._serialized_end=587
  _COUNT._serialized_start=589
  _COUNT._serialized_end=652
  _COUNTREPLY._serialized_start=654
  _COUNTREPLY._serialized_end=682
  _INSERTONE._serialized_start=684
  _INSERTONE._serialized_end=755
  _INSERTONEREPLY._serialized_start=757
  _INSERTONEREPLY._serialized_end=789
  _INSERTMANY._serialized_start=791
  _INSERTMANY._serialized_end=885
  _INSERTMANYREPLY._serialized_start=887
  _INSERTMANYREPLY._serialized_end=921
  _UPDATEONE._serialized_start=923
  _UPDATEONE._serialized_end=994
  _UPDATEONEREPLY._serialized_start=996
  _UPDATEONEREPLY._serialized_end=1028
  _UPDATEDOCUMENT._serialized_start=1030
  _UPDATEDOCUMENT._serialized_end=1125
  _UPDATERESULT._serialized_start=1127
  _UPDATERESULT._serialized_end=1251
  _UPDATEDOCUMENTREPLY._serialized_start=1253
  _UPDATEDOCUMENTREPLY._serialized_end=1315
  _INSERTORUPDATEONE._serialized_start=1317
  _INSERTORUPDATEONE._serialized_end=1415
  _INSERTORUPDATEONEREPLY._serialized_start=1417
  _INSERTORUPDATEONEREPLY._serialized_end=1457
  _INSERTORUPDATEMANY._serialized_start=1459
  _INSERTORUPDATEMANY._serialized_end=1580
  _INSERTORUPDATEMANYREPLY._serialized_start=1582
  _INSERTORUPDATEMANYREPLY._serialized_end=1624
  _DELETEONE._serialized_start=1626
  _DELETEONE._serialized_end=1692
  _DELETEONEREPLY._serialized_start=1694
  _DELETEONEREPLY._serialized_end=1732
  _DELETEMANY._serialized_start=1734
  _DELETEMANY._serialized_end=1817
  _DELETEMANYREPLY._serialized_start=1819
  _DELETEMANYREPLY._serialized_end=1858
# @@protoc_insertion_point(module_scope)



import subprocess, sys, os, pathlib
import asyncio
import openiap
import zipfile, shutil, gzip
def getpackagepath(packagepath, first=True):
    if os.path.isfile( os.path.join(packagepath, "main.py")): return packagepath
    if os.path.isfile( os.path.join(packagepath, "index.py")): return packagepath
    if os.path.isfile( os.path.join(packagepath, "agent.py")): return packagepath
    if(not first): return ""
    if not os.path.exists(packagepath): return ""
    files = os.listdir(packagepath)
    for file in files:
        dir = os.path.join(packagepath, file)
        if not os.path.isfile(dir):
            result = getpackagepath(dir, False)
            if(result != ""): return result
    return ""
def getscriptpath(packagepath):
    if os.path.isfile( os.path.join(packagepath, "main.py")): return os.path.join(packagepath, "main.py")
    if os.path.isfile( os.path.join(packagepath, "index.py")): return os.path.join(packagepath, "index.py")
    if os.path.isfile( os.path.join(packagepath, "agent.py")): return os.path.join(packagepath, "agent.py")
    return ""
def gitclone(url):
    directory = "package"
    if not os.path.exists(directory):
        subprocess.check_call(["git", "clone", "--recursive", url, directory])
    return directory
def pipinstall(packagepath):
    if os.path.isfile( os.path.join(packagepath, "requirements.txt")):
        subprocess.check_call([sys.executable, "-m", "pip", "install", "-r", os.path.join(packagepath, "requirements.txt")])
def runit(command):
    return subprocess.check_output([sys.executable, command])
def gunzip_shutil(source_filepath, dest_filepath, block_size=65536):
    with gzip.open(source_filepath, 'rb') as s_file, \
            open(dest_filepath, 'wb') as d_file:
        shutil.copyfileobj(s_file, d_file, block_size)
async def getpackage(fileid):
    directory = "package"
    c = openiap.Client()
    await c.Signin()
    result = await c.DownloadFile(Id=fileid)
    c.Close()
    if(result.filename == ""):
        raise ValueError("Filename missing or not found")
    if(pathlib.Path(result.filename).suffix == ".zip"):
        with zipfile.ZipFile(result.filename, 'r') as zip_ref:
            zip_ref.extractall(directory)
    elif(pathlib.Path(result.filename).suffix == ".gz"):
        gunzip_shutil(result.filename, directory)
    else:
        shutil.copyfile(result.filename, os.path.join(directory, result.filename))
    return directory
if __name__ == '__main__':
    packagepath = os.environ.get("packagepath", "")
    fileid = os.environ.get("fileid", "")
    gitrepo = os.environ.get("gitrepo", "")
    if(gitrepo != ""):
        packagepath = gitclone(gitrepo)
    if(fileid != ""):
        packagepath = asyncio.run(getpackage(fileid))
        print(packagepath)
    packagepath = getpackagepath(packagepath)
    if(packagepath == ""):
        sys.exit(f"packagepath not found, EXIT!")
    command = getscriptpath(packagepath)
    if command == "":
        sys.exit(f"Failed locating a command to run, EXIT!")
    pipinstall(packagepath)
    print(runit(command).decode('utf-8'))



import os, sys
import json
import traceback
import asyncio
import logging
import zlib
import openiap
from google.protobuf import any_pb2 
from proto import base_pb2_grpc, base_pb2
from google.protobuf import json_format

async def onmessage(client, command, rid, message):
    reply = base_pb2.envelope(command=command)
    reply.rid = rid
    try:
        if(command == "getelement"):
            logging.info(f"Server sent getelement {message.xpath}")
            reply.data.Pack(base_pb2.getelement(xpath=f"Did you say {message.xpath} ?"))
        elif(command == "queueevent"):
            data = json.loads(message.data);
            logging.info(f"{str(data['name'])}")
        elif(command == "error"):
            reply.command = "noop"
            logging.error(f"{str(message.message)}")
        else:
            reply.command = "error"
            reply.data.Pack(base_pb2.error(message=f"Unknown command {command}"))
            logging.error(f"Got message with unknown command {command}")
    except Exception as e:
        print("onmessage EXCEPTION!!!!")
        print(repr(e))
        traceback.print_tb(e.__traceback__)
    return reply
async def findme333(message):
    data = json.loads(message.data);
    logging.info(f"findme333: {str(data['name'])}")
async def findme222(message):
    data = json.loads(message.data);
    try:
        logging.info(f"findme222: {str(data['name'])}")
    except:
        logging.info(f"findme222: {str(data['payload']['name'])}")
        pass

async def main():
    loglevel = os.environ.get("loglevel", logging.INFO)
    if loglevel==logging.INFO:
        logging.basicConfig(format="%(message)s", level=loglevel)
    else:
        logging.basicConfig(format="%(levelname)s:%(message)s", level=loglevel)
    # c = client.Client("grpc://testuser:testuser@localhost:50051")
    apiurl = os.environ.get("apiurl", "")
    if(apiurl == ""):
        sys.exit(f"apiurl missing")
    c = openiap.Client(apiurl)
    c.onmessage = onmessage
    try:
        user = await c.Signin()
        logging.info(f"Signed in as {user.name}")
        q = await c.RegisterQueue("findme333", findme333)
        logging.info(f"Registered queue {q}")
        q = await c.RegisterQueue("findme222", findme222)
        logging.info(f"Registered queue {q}")
    except (Exception,BaseException) as e:
        print("MAIN EXCEPTION!!!!")
        print(repr(e))
        traceback.print_tb(e.__traceback__)
        pass
    
    while True:
        #try:
            text = input("COMMAND")
            print(f"PROCESSING {text}")
            if text == "f":
                # filename = "/home/allan/Pictures/allan.png"
                id = "63d66fe01465b11939cd0d2d"
                name = "download.png";
                await c.DownloadFile(Id=id)
            elif text == "p":
                workitem = {"name": "Allan", "test":"Hi mom", "age":23, "files": []}
                filepath = "/home/allan/Pictures/allan.png"
                result = await c.PushWorkitem("q2", "find me", workitem, [filepath], compressed=True)
                logging.info(f"Workitem pushed with id {result._id}")

                workitem = await c.PopWorkitem("q2", True, True)
                if(workitem == None):
                    logging.info("No more workitems in queue q2")                    
                else:
                    try:
                        for f in workitem.files:
                            if f.compressed:
                                with open("download.png", "wb") as out_file:
                                    out_file.write(zlib.decompress(f.file))
                            else:
                                with open("download.png", "wb") as out_file:
                                    out_file.write(f.file)
                        logging.info(f"Popped workitem id {workitem._id}")
                        workitem.state = "successful"
                        payload = json.loads(workitem.payload)
                        logging.info(f"payload name {payload.get('name','unnamed')} workitem name {workitem.name}")
                        payload["name"] = "Allan 2222"
                        workitem.payload = json.dumps(payload)
                        workitem = await c.UpdateWorkitem(workitem)
                        logging.info(f"Popped workitem id {workitem._id} now in state {workitem.state}")
                    except (Exception,BaseException) as e:
                         workitem.state = "retry"
                         workitem.errortype = "business" # business / application
                         workitem.errormessage = "".join(traceback.format_exception_only(type(e), e)).strip()
                         workitem.errorsource = "".join(traceback.format_exception(e))
                         await c.UpdateWorkitem(workitem)
                         print("Workitem EXCEPTION!!!!")
                         print(repr(e))
                         traceback.print_tb(e.__traceback__)
                         pass
            elif text == "s":
                signin = await c.Signin()
                logging.info(f"Signed in as {signin.name}")
            elif text == "q":
                await c.QueueMessage("findme222", '{"name":"py find me"}')
            elif text == "push":
                workitem = {"test":"Hi mom", "age":23}
                result = await c.PushWorkitem("q2", "find me", workitem)
                logging.info(f"Workitem pushed with id {result._id}")
            else:
                xpath = await c.GetElement(text)
                logging.info(xpath)
        # except (Exception,BaseException) as e:
        #     print("MAIN EXCEPTION!!!!")
        #     print(repr(e))
        #     traceback.print_tb(e.__traceback__)
        #     pass
if __name__ == "__main__":
    asyncio.run(main())



from urllib.parse import urlparse
from queue import Queue
import traceback
#import queue
import gzip
import os
import json
from datetime import datetime
# from concurrent import futures
import asyncio
import random
import time
import logging
import functools
import threading

import grpc
from proto.base_pb2_grpc import grpcServiceStub
from proto.base_pb2 import envelope
from proto import base_pb2
from proto import queues_pb2
from proto import workitems_pb2

class Client():
    def __init__(self, url = ""):
        self.url = url
        if(self.url == None or self.url == ""): 
            self.url = os.environ.get("apiurl", "")
            self.jwt = os.environ.get("jwt", "")
            if(self.jwt == ""):
                uri = urlparse(self.url)
                if(uri.username == None or uri.username == "" or uri.password == None or uri.password == ""):
                    raise ValueError("No jwt environment variable and no credentials in url")
        if(self.url == None or self.url == ""): self.url = "grpc://grpc.app.openiap.io:443"
        self.connected = False
        self.loop = asyncio.get_event_loop()
        asyncio.set_event_loop(self.loop)
        self.streams = {}
        self.pending = {}
        self.messagequeues = {}
        self.queue = Queue()
        threading.Thread(target=self.__listen_for_messages, daemon=True).start()
        # self.send_queue = queue.SimpleQueue() # or Queue if using Python before 3.7
        # threading.Thread(target=self.__server_pinger, args=(queue,)).start()
        # threading.Thread(target=self.__listen_for_messages, args=(queue,)).start()
        # threading.Thread(target=self.__server_pinger, daemon=True).start()

        # uri = urlparse(self.url)
        # if(uri.username != None and uri.username != "" and uri.password != None and uri.password != ""):
        #     self.__login_event = threading.Event()
        #     threading.Thread(target=self.__Signin, args=(uri.username, uri.password,)).start()
        #     self.__login_event.wait(timeout=None)
    def uniqueid(self):
        self.seed = random.getrandbits(32)
        while True:
            yield self.seed
            self.seed += 1
    def __Unpack(self, message):
        if(message.command == "getelement"):
            msg = base_pb2.getelement()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "signinreply"):
            msg = base_pb2.signinreply()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "registerqueuereply"):
            msg = queues_pb2.registerqueuereply()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "queuemessagereply"):
            msg = queues_pb2.queuemessagereply()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "queueevent"):
            msg = queues_pb2.queueevent()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "pushworkitemreply"):
            msg = workitems_pb2.pushworkitemreply()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "popworkitemreply"):
            msg = workitems_pb2.popworkitemreply()
            if(message.data.value != None and message.data.value != "" and message.data.value != b""):
                msg.ParseFromString(message.data.value);
                return msg
            else:
                return None
        elif(message.command == "updateworkitemreply"):
            msg = workitems_pb2.updateworkitemreply()
            if(message.data.value != None and message.data.value != "" and message.data.value != b""):
                msg.ParseFromString(message.data.value);
                return msg
            else:
                return None                
        elif(message.command == "pong"):
            msg = base_pb2.pong()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "error"):
            msg = base_pb2.error()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "download"):
            msg = base_pb2.download()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "downloadreply"):
            msg = base_pb2.downloadreply()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "stream"):
            msg = base_pb2.stream()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "beginstream"):
            msg = base_pb2.beginstream()
            msg.ParseFromString(message.data.value);
            return msg
        elif(message.command == "endstream"):
            msg = base_pb2.endstream()
            msg.ParseFromString(message.data.value);
            return msg
        else:
            logging.error(f"Got unknown {message.command} message")
            return None
    def __connect_and_listen(self, itr):
        try:
            uri = urlparse(self.url)
            logging.info(f"Connecting to {uri.hostname}:")
            if(uri.port == 443 or uri.port == "443"):
                credentials = grpc.ssl_channel_credentials()
                self.chan = grpc.secure_channel(f"{uri.hostname}:{uri.port}", credentials, options=(('grpc.ssl_target_name_override', uri.hostname),))
            else:
                self.chan = grpc.insecure_channel(f"{uri.hostname}:{uri.port}")
            fut = grpc.channel_ready_future(self.chan)
            while not fut.done():
                logging.debug("channel is not ready")
                time.sleep(1)
            self.connected = True
            logging.debug(f"Create stub and connect streams")
            stub = grpcServiceStub(self.chan)
            for message in stub.SetupStream(itr):
                logging.debug(f"RCV[{message.id}][{message.rid}][{message.command}]")
                self.__parse_message(message)
        except Exception as e:
            if(self.connected == True):
                self.connected = False
                print(repr(e))
                traceback.print_tb(e.__traceback__)
            pass
        logging.debug(f"Close channels")
        for id in self.pending:
            err = ValueError("Channel closed")
            self.loop.call_soon_threadsafe(self.pending[id].set_exception, err)
        for id in self.pending:
            err = ValueError("Channel closed")
            self.loop.call_soon_threadsafe(self.pending[id].set_exception, err)
        self.chan.close()
    def Close(self):
        if(self.connected == True):
            self.connected = False
            self.chan.close()
    async def onmessage(self, client, command, rid, message):
        logging.info(f"Got {command} message event")
    def __parse_message(self, message):
        msg = self.__Unpack(message)
        if(message.rid in self.streams and message.command in ["beginstream", "stream", "endstream"]):
            # if(message.command == "beginstream"):
            # elif(message.command == "endstream"):
            if(message.command == "stream"):
                # self.streams[message.rid] += msg.data
                self.streams[message.rid].extend(msg.data)
        elif(message.rid in self.pending):
            if(message.command == "error"):
                #raise ValueError(msg.message)
                self.loop.call_soon_threadsafe(self.pending[message.rid].set_exception, ValueError(f"SERVER ERROR {msg.message}\n{msg.stack}" ))
            else:
                self.loop.call_soon_threadsafe(self.pending[message.rid].set_result, msg)
            self.pending.pop(message.rid, None)
        else:
            if(message.command == "queueevent" and msg.queuename in self.messagequeues):
                asyncio.run(self.messagequeues[msg.queuename](msg))
            else:
                # self.trigger("message", message.command, message.id, msg)
                reply = asyncio.run(self.onmessage(self, message.command, message.id, msg))
                if(reply.command != "noop"):
                    self.Send(reply, message.id)
    def __server_pinger(self):
        count = 0
        while True:
            time.sleep(5)
            asyncio.run(self.__ping())
            # message = envelope(command="ping")
            # self.queue.put(message)
            count += 1
    def __request_iterator(self, connectonid):
        logging.debug(f"Waiting for message for connecton id {connectonid}")
        message = self.queue.get()
        if(connectonid != self.connectonid):
            self.queue.put(message)
            return None
        logging.debug(f"Process sending message for connecton id {connectonid}")
        if(message.id == None or message.id == ""): message.id = str(next(self.uniqueid()))
        logging.debug(f"SND[{message.id}][{message.rid}][{message.command}]")
        return(message)

    def __listen_for_messages(self):
        while True:
            self.connectonid = str(next(self.uniqueid()))
            count = 0
            logging.debug(f"Estabilish connecton id {self.connectonid}")
            self.__connect_and_listen(
                iter(functools.partial(self.__request_iterator, self.connectonid), None)
            )
            self.connected = False
            count += 1
            logging.debug(f"Reconnect number {count}")
            time.sleep(2)
    def __SetStream(self, rid):
        # self.streams[rid] = b""
        self.streams[rid] = bytearray(0)
    def __RPC(self, request, id=None):
        if(id == None): id = str(next(self.uniqueid()))
        request.id = id
        future = asyncio.Future()
        self.pending[id] = future
        self.queue.put(request)
        return future
    async def __ping(self):
        # self.__Send(base_pb2.envelope(command="ping"), "")
        # self.queue.put(base_pb2.envelope(command="ping"))
        await self.__RPC(base_pb2.envelope(command="ping"))
    def Send(self, request, rid):
        if(rid == None or rid == ""): raise ValueError("RID is mandatory")
        id = str(next(self.uniqueid()))
        request.id = id
        request.rid = rid
        self.queue.put(request)
        # 
    def __Signin(self, username, password):
        signin = asyncio.run(self.Signin(username, password))
        logging.info(f"Signed in as {signin.name}" )
        self.__login_event.set()
    async def Signin(self, username=None, password=None):
        request = base_pb2.envelope(command="signin")
        if(username == None and password==None):
            jwt = os.environ.get("jwt", "")
            if jwt != "":
                username=jwt
            else:
                uri = urlparse(self.url)
                if(uri.username != None and uri.username != "" and uri.password != None and uri.password != ""):
                    username=uri.username
                    password=uri.password
        if(password== None or password == ""):
            request.data.Pack(base_pb2.signin(jwt=username))
        else:
            request.data.Pack(base_pb2.signin(username=username, password=password))
        result = await self.__RPC(request)
        self.jwt = result.jwt
        self.user = result.user
        return result.user
    async def DownloadFile(self, Id=None, Filename=None):
        request = base_pb2.envelope(command="download")
        request.data.Pack(base_pb2.download(filename=Filename,id=Id))
        rid = str(next(self.uniqueid()))
        self.__SetStream(rid)
        promise = self.__RPC(request, rid)
        result = await promise
        if(result.filename != None and result.filename != ""):
            with open(result.filename, "wb") as out_file:
                out_file.write(self.streams[rid])
        return result
    async def GetElement(self, xpath):
        request = base_pb2.envelope(command="getelement")
        request.data.Pack(base_pb2.getelement(xpath=xpath))
        result = await self.__RPC(request)
        return result.xpath
    async def RegisterQueue(self, queuename, callback):
        request = base_pb2.envelope(command="registerqueue")
        request.data.Pack(queues_pb2.registerqueue(queuename=queuename))
        result = await self.__RPC(request)
        self.messagequeues[result.queuename] = callback
        return result.queuename
    async def QueueMessage(self, queuename, data):
        request = base_pb2.envelope(command="queuemessage")
        request.data.Pack(queues_pb2.queuemessage(queuename=queuename, data=data, striptoken=True))
        return self.__RPC(request)
    async def PushWorkitem(self, wiq:str, name:str, payload:dict, files: any = None, wiqid:str = None, nextrun: datetime = None, priority: int = 2, compressed: bool = False):
        request = base_pb2.envelope(command="pushworkitem")
        _files = []
        if(files != None):
            for filepath in files:
                filename = os.path.basename(filepath)
                if compressed == True:
                    with open(filepath, mode="rb") as content:
                        _files.append({"filename":filename, "compressed": compressed, "file": gzip.compress(content.read())})
                else:
                    with open(filepath, mode="rb") as content:
                        _files.append({"filename":filename, "compressed": compressed, "file": content.read()})
        q = workitems_pb2.pushworkitem(wiq=wiq,name=name, files=_files, wiqid=wiqid, nextrun=nextrun, priority=priority )
        q.payload = json.dumps(payload)
        request.data.Pack(q)
        result = await self.__RPC(request)
        return result.workitem;
    async def PopWorkitem(self, wiq:str,includefiles:bool=False,compressed:bool=False):
        request = base_pb2.envelope(command="popworkitem")
        request.data.Pack(workitems_pb2.popworkitem(wiq=wiq,includefiles=includefiles,compressed=compressed))
        result = await self.__RPC(request)
        if(result == None): return None
        return result.workitem;
    async def UpdateWorkitem(self, workitem):
        request = base_pb2.envelope(command="updateworkitem")
        uwi = workitems_pb2.updateworkitem(workitem = workitem);
        request.data.Pack(uwi)
        result = await self.__RPC(request)
        if(result == None): return None
        return result.workitem;



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: watch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bwatch.proto\x12\x07openiap\".\n\x05watch\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\"\x18\n\nwatchreply\x12\n\n\x02id\x18\x01 \x01(\t\"=\n\nwatchevent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x10\n\x08\x64ocument\x18\x03 \x01(\t\"\x15\n\x07unwatch\x12\n\n\x02id\x18\x01 \x01(\t\"\x0e\n\x0cunwatchreplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'watch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WATCH._serialized_start=24
  _WATCH._serialized_end=70
  _WATCHREPLY._serialized_start=72
  _WATCHREPLY._serialized_end=96
  _WATCHEVENT._serialized_start=98
  _WATCHEVENT._serialized_end=159
  _UNWATCH._serialized_start=161
  _UNWATCH._serialized_end=182
  _UNWATCHREPLY._serialized_start=184
  _UNWATCHREPLY._serialized_end=198
# @@protoc_insertion_point(module_scope)
